# To Dos
## For MVP
- [x] Switch over to structured responses using pydantic
- [x] Add resource versions of question
- [x] Add instructions for how to set up with Claude Code
- [ ] Remove null fields from responses to avoid wasting context
- [x] Clean up test_client.py, since Claude has left it a bit of a mess
- [x] Set up GitHub CI for linting, tests, etc.
